Struct token_cell::core::TokenCell

source ·
pub struct TokenCell<T: ?Sized, Token: TokenTrait> { /* private fields */ }
A Cell that shifts the management of access permissions to its inner value onto a Token.

Implementations

Methods from Deref<Target = UnsafeCell<T>>

Gets a mutable pointer to the wrapped value.

This can be cast to a pointer of any kind. Ensure that the access is unique (no active references, mutable or not) when casting to &mut T, and ensure that there are no mutations or mutable aliases going on when casting to &T

Examples
use std::cell::UnsafeCell;

let uc = UnsafeCell::new(5);

let five = uc.get();

Returns a mutable reference to the underlying data.

This call borrows the UnsafeCell mutably (at compile-time) which guarantees that we possess the only reference.

Examples
use std::cell::UnsafeCell;

let mut c = UnsafeCell::new(5);
*c.get_mut() += 1;

assert_eq!(*c.get_mut(), 6);