Module runtime_token_support

Module runtime_token_support 

Support module for the runtime_token macro.

Structs

IdMismatch
The comparison error for runtime tokens.

Traits

Identifier
A trait for types that can serve as unique identifiers for runtime tokens.
RollingCounter
A trait for types that can be used as rolling counters. It is only intended for the atomic counterparts to Identifier types.