RuntimeToken

Struct RuntimeToken 

pub struct RuntimeToken(/* private fields */);
The default runtime-checked token type.

Because this token type is checked at runtime, it can make sense to have a global token type for your whole application.

And because this runtime token is backed by a u64, it would take you 60 years continuously instantiating them at 10GHz (which is unfeasible with existing hardware) before an overflow may cause multiple tokens to share the same runtime identifier; so you can safely assume that this token type will never let you access a cell that you shouldn’t be accessing.