Struct token_cell::TokenCell[−][src]

#[repr(C)]
pub struct TokenCell<Token: TokenTrait, T> { /* fields omitted */ }
A cell which requires a token for interior read/write access.

Implementations

Borrows the cell’s content.

Borrows the cell’s content mutably.

Places value inside the cell, returning the

Builds a TokenCell attached to a token

Builds a TokenCell attached to a token

Fallible equivalent of TokenCell::swap, for runtime-checked tokens.

Since token mismatch is indicative that the wrong token was used to interact with the cell, you should treat these as unrecoverable errors by unwrapping the result.

Fallible equivalent of TokenCell::borrow, for runtime-checked tokens.

Since token mismatch is indicative that the wrong token was used to interact with the cell, you should treat these as unrecoverable errors by unwrapping the result.

Fallible equivalent of TokenCell::borrow_mut, for runtime-checked tokens.

Since token mismatch is indicative that the wrong token was used to interact with the cell, you should treat these as unrecoverable errors by unwrapping the result.