Struct token_cell::ghost::GhostToken
source · pub struct GhostToken<'brand>(_);Expand description
WARNING: This attempt at recreating GhostCell but with traits does NOT work.
I am leaving this here because I believe there may exist a way to make this type of token work, and anyone who has ideas of how to do so is welcome to try and make a PR.
To check your theory, clone this repo and use the ghost.rs example as a check for
your attempt. If your method works, the example should have some compile error.