IdMismatch

Struct IdMismatch 

pub struct IdMismatch<T: Identifier> {
    pub cell: T,
    pub token: T,
}
The comparison error for runtime tokens.

Such an error being returned implies a massive bug in the calling code, as it implies that said code failed to track which instance of a [runtime_token] was used to construct a cell, and thus failed to ensure that the token was used correctly.

Unless the token is backed by an integer with sufficient size to guarantee that the program never constructs multiple tokens with a same identifier, your program SHOULD NOT rely on token identifiers being unique for soundness.

Fields

cell: T

The identifier of the token the cell was expecting.

token: T

The identifier of the token that was used to attempt accessing the cell’s contents.