pub trait RollingCounter {
type NonAtomic;
const DEFAULT: Self;
// Required method
fn next(&self) -> Self::NonAtomic;
}Expand description
A trait for types that can be used as rolling counters. It is only intended for the atomic counterparts to Identifier types.
Required Associated Constants
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.