Trait token_cell::support::TokenTrait [−][src]
pub trait TokenTrait: Sized {
type Checker: TokenChecker<Self>;
}Expand description
Must be implemented by any token type and ideally its only constructor.
The easiest way to create a token type is with [generate_token], which will create a ZST which implements TokenTrait